Class: Aws::IoT1ClickProjects::Types::PlacementSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iot1clickprojects/types.rb

Overview

An object providing summary information for a particular placement.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_dateTime

The date when the placement was originally created, in UNIX epoch time format.



416
417
418
419
420
421
422
423
# File 'lib/aws-sdk-iot1clickprojects/types.rb', line 416

class PlacementSummary < Struct.new(
  :project_name,
  :placement_name,
  :created_date,
  :updated_date)
  SENSITIVE = []
  include Aws::Structure
end

#placement_nameString

The name of the placement being summarized.



416
417
418
419
420
421
422
423
# File 'lib/aws-sdk-iot1clickprojects/types.rb', line 416

class PlacementSummary < Struct.new(
  :project_name,
  :placement_name,
  :created_date,
  :updated_date)
  SENSITIVE = []
  include Aws::Structure
end

#project_nameString

The name of the project containing the placement.



416
417
418
419
420
421
422
423
# File 'lib/aws-sdk-iot1clickprojects/types.rb', line 416

class PlacementSummary < Struct.new(
  :project_name,
  :placement_name,
  :created_date,
  :updated_date)
  SENSITIVE = []
  include Aws::Structure
end

#updated_dateTime

The date when the placement was last updated, in UNIX epoch time format. If the placement was not updated, then createdDate and updatedDate are the same.



416
417
418
419
420
421
422
423
# File 'lib/aws-sdk-iot1clickprojects/types.rb', line 416

class PlacementSummary < Struct.new(
  :project_name,
  :placement_name,
  :created_date,
  :updated_date)
  SENSITIVE = []
  include Aws::Structure
end